@@ -31,11 +31,9 @@ class CustomS3JsonWriter:
             - this way, we ensure all data is original and in its most updated state.
         """
         dimension = json_data["dimension"]
-        date = json_data["date"].replace('-', '')
+        date = json_data["date"].replace("-", "")
         dataset = json_data["data"]
-        #metric = json_data["metric"]
+        # metric = json_data["metric"]
         key_path = f"{self.file_path}/{dimension}/{date}.json"
         print(f"Writing data to {key_path}.")
-        self.s3_resource.Object(self.bucket, key_path).put(
-            Body=json.dumps(dataset)
-        )
+        self.s3_resource.Object(self.bucket, key_path).put(Body=json.dumps(dataset))
